
---
# Thermostat 5 click

> PRVIH_PAR_RECENICA_SA_PRODUCT_PAGE_DA_ISPRATE_CELINU

<p align="center">
  <img src="CLICK_IMAGE_LINK" height=300px>
</p>

[click Product page](CLICK_PRODUCT_PAGE_LINK)

---


#### Click library

- **Author**        : Nenad Filipovic
- **Date**          : Feb 2024.
- **Type**          : ADC/I2C type


# Software Support

We provide a library for the Thermostat 5 Click
as well as a demo application (example), developed using MikroElektronika
[compilers](https://www.mikroe.com/necto-studio).
The demo can run on all the main MikroElektronika [development boards](https://www.mikroe.com/development-boards).

Package can be downloaded/installed directly from *NECTO Studio Package Manager*(recommended way), downloaded from our [LibStock&trade;](https://libstock.mikroe.com) or found on [Mikroe github account](https://github.com/MikroElektronika/mikrosdk_click_v2/tree/master/clicks).

## Library Description

> This library contains API for Thermostat 5 Click driver.

#### Standard key functions :

- `thermostat5_cfg_setup` Config Object Initialization function.
```c
void thermostat5_cfg_setup ( thermostat5_cfg_t *cfg );
```

- `thermostat5_init` Initialization function.
```c
err_t thermostat5_init ( thermostat5_t *ctx, thermostat5_cfg_t *cfg );
```

#### Example key functions :

- `thermostat5_set_relay` This function controls the relay by setting the state of the ON (PWM) pin.
```c
void thermostat5_set_relay ( thermostat5_t *ctx, uint8_t state );
```

- `thermostat5_get_temperature` This function reads and calculates temperature in degrees Celsius [degC] using NTC thermistors.
```c
err_t thermostat5_get_temperature ( thermostat5_t *ctx, float *temperature );
```

- `thermostat5_read_voltage` This function sets the voltage reference for Thermostat 5 click driver.
```c
err_t thermostat5_read_voltage ( thermostat5_t *ctx, float *voltage );
```

## Example Description

> This library contains API for the Thermostat 5 Click driver 
> for temperature measurement and relay control.

**The demo application is composed of two sections :**

### Application Init

> The initialization of the I2C or ADC module and log UART set the relay to an OFF state.

```c
void application_init ( void )
{
    log_cfg_t log_cfg;  /**< Logger config object. */
    thermostat5_cfg_t thermostat5_cfg;  /**< Click config object. */

    /** 
     * Logger initialization.
     * Default baud rate: 115200
     * Default log level: LOG_LEVEL_DEBUG
     * @note If USB_UART_RX and USB_UART_TX 
     * are defined as HAL_PIN_NC, you will 
     * need to define them manually for log to work. 
     * See @b LOG_MAP_USB_UART macro definition for detailed explanation.
     */
    LOG_MAP_USB_UART( log_cfg );
    log_init( &logger, &log_cfg );
    log_info( &logger, " Application Init " );

    // Click initialization.
    thermostat5_cfg_setup( &thermostat5_cfg );
    THERMOSTAT5_MAP_MIKROBUS( thermostat5_cfg, MIKROBUS_1 );
    err_t init_flag = thermostat5_init( &thermostat5, &thermostat5_cfg );
    if ( ( ADC_ERROR == init_flag ) || ( I2C_MASTER_ERROR == init_flag ) )
    {
        log_error( &logger, " Communication init." );
        for ( ; ; );
    }

    thermostat5_set_relay( &thermostat5, THERMOSTAT5_RELAY_OFF );
    log_info( &logger, " Application Task " );
    Delay_ms( 100 );
}
```

### Application Task

> The demo application measures temperature in degrees Celsius.
> If the temperature increases above 30 degrees Celsius, 
> the relay will turn ON, otherwise it will turn OFF.
> Results are being sent to the UART Terminal, where you can track their changes.

```c
void application_task ( void ) 
{
    float temperature = 0;
    if ( THERMOSTAT5_OK == thermostat5_get_temperature( &thermostat5, &temperature ) )
    {
        log_printf( &logger, " Temperatur : %.2f [degC]\r\n", temperature );
        if ( THERMOSTAT5_TEMPERATURE_LIMIT < temperature )
        {
            thermostat5_set_relay( &thermostat5, THERMOSTAT5_RELAY_ON );
            log_printf( &logger, " Relay: ON\r\n" );
        }
        else
        {
            thermostat5_set_relay( &thermostat5, THERMOSTAT5_RELAY_OFF );
            log_printf( &logger, " Relay: OFF\r\n" );
        }
        Delay_ms( 1000 );
    }
}
```

## Note

> For temperature measurement, we used Semitec 103AT-2 NTC Thermistors. 
> - Beta parameter:  3435 K	
> - Resistance:      10 kOhms	
> - Tolerance:	      1 %

The full application code, and ready to use projects can be installed directly from *NECTO Studio Package Manager*(recommended way), downloaded from our [LibStock&trade;](https://libstock.mikroe.com) or found on [Mikroe github account](https://github.com/MikroElektronika/mikrosdk_click_v2/tree/master/clicks).

**Other Mikroe Libraries used in the example:**

- MikroSDK.Board
- MikroSDK.Log
- Click.Thermostat5

**Additional notes and informations**

Depending on the development board you are using, you may need
[USB UART click](https://www.mikroe.com/usb-uart-click),
[USB UART 2 Click](https://www.mikroe.com/usb-uart-2-click) or
[RS232 Click](https://www.mikroe.com/rs232-click) to connect to your PC, for
development systems with no UART to USB interface available on the board. UART
terminal is available in all MikroElektronika
[compilers](https://shop.mikroe.com/compilers).

---
